fn validate_model(
model: ApiResponse,
options: &FetchOptions,
) -> Result<Project, QueryError>Expand description
Validates the response from the GitLab API by checking for GraphQL errors, and if the project can be accessed.
fn validate_model(
model: ApiResponse,
options: &FetchOptions,
) -> Result<Project, QueryError>Validates the response from the GitLab API by checking for GraphQL errors, and if the project can be accessed.